@@ -1,12 +1,9 @@
 package Akado::Account;
+{
+  $Akado::Account::VERSION = '0.03';
+}
 
-=head1 NAME
-
-Akado::Account - get internet provider Akado account info
-
-=cut
-
-our $VERSION = '0.02';
+# ABSTRACT: get internet provider Akado account info
 
 use strict;
 use warnings FATAL => 'all';
@@ -18,33 +15,6 @@ use HTTP::Request::Common;
 use LWP;
 use XML::XPath;
 
-=head1 SYNOPSIS
-
-Akado is the internet provider that works in Moscow, Russia.
-L<http://www.akado.ru/>
-
-Every Akado customer has access to the site L<https://office.akado.ru/> where
-he can see his account info. This module creates Perl object that gets account
-info from that site.
-
-Unfortunately Akdado account site has no API, so this module acts as a browser
-to get needed info.
-
-Every module method dies in case of error.
-
-=head1 METHODS
-
-=head2 new
-
-This a constuctor. It creates object. The constractor will not access the
-account site. All network interaction is made in the methods that return data.
-
-    my $aa = Akado::Account->new({
-        login => $login,
-        password => $password,
-    });
-
-=cut
 
 sub new {
     my ($class, $self) = @_;
@@ -58,20 +28,6 @@ sub new {
     return $self;
 }
 
-=head2 get_balance
-
-It will return number. The number is the sum of money that is left on the
-user account. The currencty is RUB (Russian rouble).
-
-    say $aa->get_balance();     # will print '749.82', or something like this
-
-If the object hasn't accessed the Akado account site
-L<https://office.akado.ru/> since the object was created, the method will
-access site, get data from it and store it in the object. The object will
-access Akado site only once, after saving data in the object all methods use
-that cached data.
-
-=cut
 
 sub get_balance {
     my ($self) = @_;
@@ -80,20 +36,6 @@ sub get_balance {
     return $data->{balance};
 }
 
-=head2 get_next_month_payment
-
-It will return number. The number is the sum of money that the user will have
-to pay for the next month. The currencty is RUB (Russian rouble).
-
-    say $aa->get_next_month_payment();
-
-If the object hasn't accessed the Akado account site
-L<https://office.akado.ru/> since the object was created, the method will
-access site, get data from it and store it in the object. The object will
-access Akado site only once, after saving data in the object all methods use
-that cached data.
-
-=cut
 
 sub get_next_month_payment {
     my ($self) = @_;
@@ -102,32 +44,6 @@ sub get_next_month_payment {
     return $data->{next_month_payment};
 }
 
-=begin comment _get_cached_parsed_data
-
-B<Get:> 1) $self
-
-B<Return:> 1) $parsed_data
-
-This is private method that should not be used outside the object.
-
-The method checks if the object has already accessed Akado site, if it hasn't
-the method gets the data from site, parses it, stores parsed data in the
-object and returnes the stored data.
-
-It the object already had accessed Akado site the method will just return
-stored parsed data.
-
-Sample of what it can return:
-
-    {
-        balance            => 749.82,
-        date               => "2012-09-29",
-        next_month_payment => 779,
-    }
-
-=end comment
-
-=cut
 
 sub _get_cached_parsed_data {
     my ($self) = @_;
@@ -140,24 +56,12 @@ sub _get_cached_parsed_data {
     return $self->{_parsed_data};
 }
 
-=begin comment _get_full_account_info_xml
-
-B<Get:> 1) $self
-
-B<Return:> 1) $xml
-
-Metod returns xml with user account info. Because the Akado site hasn't got
-API this method acts as a browser.
-
-=end comment
-
-=cut
 
 sub _get_full_account_info_xml {
     my ($self) = @_;
 
     my $browser = LWP::UserAgent->new;
-    $browser->agent("Akado::Account/$VERSION");
+    $browser->agent("Akado::Account/$Akado::Account::VERSION");
     $browser->cookie_jar( {} );
 
     # At first we need to login to the site.
@@ -174,26 +78,6 @@ sub _get_full_account_info_xml {
     return $xml;
 }
 
-=begin comment _parse_xml
-
-B<Get:> 1) $self 2) $xml
-
-B<Return:> 1) $parsed_data
-
-Metod gets xml that was previously downloaded from the Akado account site and
-returnes some data from it.
-
-It will return something like:
-
-    {
-        balance            => 1558.82,
-        date               => "2012-10-02",
-        next_month_payment => 779,
-    }
-
-=end comment
-
-=cut
 
 sub _parse_xml {
     my ($self, $xml) = @_;
@@ -213,19 +97,6 @@ sub _parse_xml {
     return $parsed_account_info;
 }
 
-=begin comment _get_auth_response
-
-B<Get:> 1) $self 2) $browser - LWP::UserAgent object
-
-B<Return:> 2) $response - HTTP::Response object
-
-The method gets LWP::UserAgent object that has cookies jar in it and logges to
-the Akado site. After the log in the cookies are stored in the $browser
-object to make it possible to access other pages.
-
-=end comment
-
-=cut
 
 sub _get_auth_response {
     my ($self, $browser) = @_;
@@ -249,18 +120,6 @@ sub _get_auth_response {
     return $response;
 }
 
-=begin comment _get_data_response
-
-B<Get:> 1) $self 2) $browser - LWP::UserAgent object
-
-B<Return:> 2) $response - HTTP::Response object
-
-The method gets LWP::UserAgent object that has session cookies in it and the
-method returns the xml page with user account data.
-
-=end comment
-
-=cut
 
 sub _get_data_response {
     my ($self, $browser) = @_;
@@ -288,18 +147,6 @@ sub _get_data_response {
     return $response;
 }
 
-=begin comment _get_data_response
-
-B<Get:> 1) $self 2) $cookies - HTTP::Cookies object
-
-B<Return:> 2) $domain - the string 'office.akado.ru' or something like this.
-
-Method gets domain part from existing cookies. This part is needed to create
-new cookie.
-
-=end comment
-
-=cut
 
 sub _get_domain_from_cookies {
     my ($self, $cookies) = @_;
@@ -315,18 +162,6 @@ sub _get_domain_from_cookies {
     return $domain
 }
 
-=begin comment _check_response
-
-B<Get:> 1) $self 2) $cookies - HTTP::Response object
-
-B<Return:> -
-
-The method checks that there was no error in accessing some page. If there was
-error, the die is performed.
-
-=end comment
-
-=cut
 
 sub _check_response {
     my ($self, $response) = @_;
@@ -340,19 +175,172 @@ sub _check_response {
     return '';
 }
 
-=head1 AUTHOR
 
-Ivan Bessarabov, C<< <ivan@bessarabov.ru> >>
+1;
 
-=head1 SOURCE CODE
+__END__
 
-The source code for this module is hosted on GitHub
-L<https://github.com/bessarabov/Akado-Account>
+=pod
 
-=head1 BUGS
+=head1 NAME
 
-Please report any bugs or feature requests in GitHub Issues
-L<https://github.com/bessarabov/Akado-Account/issues>
+Akado::Account - get internet provider Akado account info
+
+=head1 VERSION
+
+version 0.03
+
+=head1 SYNOPSIS
+
+Akado is the internet provider that works in Moscow, Russia.
+L<http://www.akado.ru/>
+
+Every Akado customer has access to the site L<https://office.akado.ru/> where
+he can see his account info. This module creates Perl object that gets account
+info from that site.
+
+Unfortunately Akdado account site has no API, so this module acts as a browser
+to get needed info.
+
+Every module method dies in case of error.
+
+=head1 METHODS
+
+=head2 new
+
+This a constuctor. It creates object. The constractor will not access the
+account site. All network interaction is made in the methods that return data.
+
+    my $aa = Akado::Account->new({
+        login => $login,
+        password => $password,
+    });
+
+=head2 get_balance
+
+It will return number. The number is the sum of money that is left on the
+user account. The currencty is RUB (Russian rouble).
+
+    say $aa->get_balance();     # will print '749.82', or something like this
+
+If the object hasn't accessed the Akado account site
+L<https://office.akado.ru/> since the object was created, the method will
+access site, get data from it and store it in the object. The object will
+access Akado site only once, after saving data in the object all methods use
+that cached data.
+
+=head2 get_next_month_payment
+
+It will return number. The number is the sum of money that the user will have
+to pay for the next month. The currencty is RUB (Russian rouble).
+
+    say $aa->get_next_month_payment();
+
+If the object hasn't accessed the Akado account site
+L<https://office.akado.ru/> since the object was created, the method will
+access site, get data from it and store it in the object. The object will
+access Akado site only once, after saving data in the object all methods use
+that cached data.
+
+=begin comment _get_cached_parsed_data
+
+B<Get:> 1) $self
+
+B<Return:> 1) $parsed_data
+
+This is private method that should not be used outside the object.
+
+The method checks if the object has already accessed Akado site, if it hasn't
+the method gets the data from site, parses it, stores parsed data in the
+object and returnes the stored data.
+
+It the object already had accessed Akado site the method will just return
+stored parsed data.
+
+Sample of what it can return:
+
+    {
+        balance            => 749.82,
+        date               => "2012-09-29",
+        next_month_payment => 779,
+    }
+
+=end comment
+
+=begin comment _get_full_account_info_xml
+
+B<Get:> 1) $self
+
+B<Return:> 1) $xml
+
+Metod returns xml with user account info. Because the Akado site hasn't got
+API this method acts as a browser.
+
+=end comment
+
+=begin comment _parse_xml
+
+B<Get:> 1) $self 2) $xml
+
+B<Return:> 1) $parsed_data
+
+Metod gets xml that was previously downloaded from the Akado account site and
+returnes some data from it.
+
+It will return something like:
+
+    {
+        balance            => 1558.82,
+        date               => "2012-10-02",
+        next_month_payment => 779,
+    }
+
+=end comment
+
+=begin comment _get_auth_response
+
+B<Get:> 1) $self 2) $browser - LWP::UserAgent object
+
+B<Return:> 2) $response - HTTP::Response object
+
+The method gets LWP::UserAgent object that has cookies jar in it and logges to
+the Akado site. After the log in the cookies are stored in the $browser
+object to make it possible to access other pages.
+
+=end comment
+
+=begin comment _get_data_response
+
+B<Get:> 1) $self 2) $browser - LWP::UserAgent object
+
+B<Return:> 2) $response - HTTP::Response object
+
+The method gets LWP::UserAgent object that has session cookies in it and the
+method returns the xml page with user account data.
+
+=end comment
+
+=begin comment _get_data_response
+
+B<Get:> 1) $self 2) $cookies - HTTP::Cookies object
+
+B<Return:> 2) $domain - the string 'office.akado.ru' or something like this.
+
+Method gets domain part from existing cookies. This part is needed to create
+new cookie.
+
+=end comment
+
+=begin comment _check_response
+
+B<Get:> 1) $self 2) $cookies - HTTP::Response object
+
+B<Return:> -
+
+The method checks that there was no error in accessing some page. If there was
+error, the die is performed.
+
+=end comment
 
 =head1 TODO
 
@@ -364,16 +352,15 @@ For now he module does not have tests. It was created interacting with the
 production system. This is not good. The test should be added that mocks Akado
 site and its data.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 AUTHOR
 
-Copyright 2012 Ivan Bessarabov.
+Ivan Bessarabov <ivan@bessarabov.ru>
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+=head1 COPYRIGHT AND LICENSE
 
-See http://dev.perl.org/licenses/ for more information.
+This software is copyright (c) 2012 by Ivan Bessarabov.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
